this.name					= "stellarSerpents_masterScript.js";
this.author					= "Thargoid";
this.copyright				= "Creative Commons: attribution, non-commercial, sharealike.";
this.description			= "Wandering and spawning of Stellar Serpent ";
this.version				= "1.21";
"use strict";

this.startUp = function()
	{
	if(!missionVariables.stellarSerpents_status)
		{ missionVariables.stellarSerpents_status = "NO_SERPENT"; } //  Whether the serpent is in the galaxy or not
	if(!missionVariables.stellarSerpents_serpentLife)
		{ missionVariables.stellarSerpents_serpentLife = 0; } //  how long the serpent has been in the galaxy
	if(!missionVariables.stellarSerpents_notification)
		{ missionVariables.stellarSerpents_notification = "INITIAL_BROADCAST"; } // OXP's opening mission screen broadcast
	}
	
this.shipWillEnterWitchspace = function()
	{
	this.actionChance = Math.random();		
	if(missionVariables.stellarSerpents_status == "SERPENT" && this.actionChance > 0.45)
		{
		if(this.actionChance < 0.9) // serpent moves system 45% of time
			{
			missionVariables.stellarSerpents_serpentLife += 1;
			var currentSystem = System.infoForSystem(galaxyNumber, missionVariables.stellarSerpents_currentLocation);
			var systemArray = currentSystem.systemsInRange(7);
			var destinationSystem = systemArray[Math.floor((Math.random()) * systemArray.length)];
			missionVariables.stellarSerpents_currentLocation = destinationSystem.systemID;
			missionVariables.stellarSerpents_locationName = destinationSystem.name;
			mission.setInstructionsKey("stellarSerpents_shortMoved", "stellarSerpents_masterScript.js");
			}
		else // serpent is destroyed by NPC 10% of time, if it has lived at least 3 jumps 
			{
			if(missionVariables.stellarSerpents_serpentLife > 3)
				{ // killed by NPC
				missionVariables.stellarSerpents_status = "NO_SERPENT";
				missionVariables.stellarSerpents_notification = "NPC_DESTROYED";
				mission.setInstructionsKey("stellarSerpents_shortNoSerpent", "stellarSerpents_masterScript.js");
				missionVariables.stellarSerpents_serpentLife = 0;
				}
			else
				{ // short-lived serpent, so keep alive and stay put
				missionVariables.stellarSerpents_serpentLife += 1;
				mission.setInstructionsKey("stellarSerpents_shortStayed", "stellarSerpents_masterScript.js");
				}			
			}
		}	
	else
		{
		if(missionVariables.stellarSerpents_status == "SERPENT")
			{ // serpent exists and stays where it was
			missionVariables.stellarSerpents_serpentLife += 1;
			mission.setInstructionsKey("stellarSerpents_shortStayed", "stellarSerpents_masterScript.js");
			}
		else
			{ // no serpents in the galaxy
			mission.setInstructionsKey("stellarSerpents_shortNoSerpent", "stellarSerpents_masterScript.js");
			}
		}
	}	

this.playerEnteredNewGalaxy = function(galaxyNumber) // reset things if we galaxy hop
	{
	missionVariables.stellarSerpents_status = "NO_SERPENT";
	mission.setInstructionsKey("stellarSerpents_shortNoSerpent", "stellarSerpents_masterScript.js");
	}
	
this.shipLaunchedFromStation = function()
	{
	this.shipExitedWitchspace();
	delete this.shipLaunchedFromStation;
	}
	
this.shipExitedWitchspace = function()
	{
	if(system.isInterstellarSpace) 
		{ // don't place serpent if we're in interstellar space
		return;
		}
	
	if(missionVariables.stellarSerpents_status == "SERPENT" && system.ID == missionVariables.stellarSerpents_currentLocation && system.countShipsWithRole("stellarSerpents_head") == 0)
		{
		system.addShipsToRoute("stellarSerpents_head", 1);
		}
		
	if(system.countShipsWithRole("stellarSerpents_head") > 0)
		{
		this.delayedMessage("Stellar Serpent's presence is confirmed in-system!",6,5);
		}
	
	this.appearanceChance = Math.random();
	if(missionVariables.stellarSerpents_status == "NO_SERPENT" && this.appearanceChance < 0.1) // add a serpent 10% of time if none present in galaxy
		{
		missionVariables.stellarSerpents_status = "SERPENT";
		missionVariables.stellarSerpents_serpentLife = 0;
		missionVariables.stellarSerpents_currentLocation = Math.floor(Math.random() * 256);
		if(galaxyNumber == 2 && (missionVariables.stellarSerpents_currentLocation == 133 || missionVariables.stellarSerpents_currentLocation == 206))
			{ // if the spawning location is one of the two unreachable systems, change it to somewhere else.
			missionVariables.stellarSerpents_currentLocation += Math.ceil(Math.random() * 40);
			}
		missionVariables.stellarSerpents_locationName = System.infoForSystem(galaxyNumber, missionVariables.stellarSerpents_currentLocation).name;
		mission.setInstructionsKey("stellarSerpents_shortAppeared", "stellarSerpents_masterScript.js");
		missionVariables.stellarSerpents_notification = "SERPENT_APPEARED";
		}
	}
	
this.delayedMessage = function(messageString, duration, delay)
	{
	this.messageTimer = new Timer(this, function() {this.displayMessage(messageString, duration);}, delay);
	}
	
this.displayMessage = function(messageString, duration)
	{
	if(messageString)
		{
		if(!duration || duration < 1)
			{
			duration = 6;
			}
		player.commsMessage(messageString, duration);
		}
	}

this.missionScreenOpportunity = function()
	{
	if(!player.ship.docked || !player.ship.dockedStation.isMainStation) 
		{
		return;
		}
	switch(missionVariables.stellarSerpents_notification)
		{
		case "INITIAL_BROADCAST":
			{
			mission.runScreen({title: "Notice to All Commanders", messageKey:"stellarSerpents_initial", background:"stellarSerpent_snakeBackground.png"});
			mission.setInstructionsKey("stellarSerpents_shortNoSerpent", "stellarSerpents_masterScript.js");
			missionVariables.stellarSerpents_notification = "NO_NOTIFICATION";
			break;
			}
		
		case "NPC_DESTROYED":
			{
			mission.runScreen({title: "Serpent Terminated", messageKey:"stellarSerpents_NPCTerminated", background:"stellarSerpent_starBackground.png"});
			missionVariables.stellarSerpents_notification = "NO_NOTIFICATION";
			break;
			}	

		case "PLAYER_DESTROYED":
			{
			mission.runScreen({title: "Serpent Terminated", messageKey:"stellarSerpents_playerTerminated", background:"stellarSerpent_starBackground.png"});
			missionVariables.stellarSerpents_notification = "NO_NOTIFICATION";
			break;
			}	
			
		case "SERPENT_APPEARED":
			{
			mission.runScreen({title: "Serpent Sighted", messageKey:"stellarSerpents_appeared", background:"stellarSerpent_snakeBackground.png"});
			missionVariables.stellarSerpents_notification = "NO_NOTIFICATION";
			break;
			}				
		}
	
	}
	
this.shipDied = function()
	{
	if(this.messageTimer && this.messageTimer.isRunning)
		{
		this.messageTimer.stop();
		}
	}